@@ -92,9 +92,11 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
                 } else {
                     let packager = found_response.packager.as_str();
                     let p = match packager {
-                        "pip" => style(format!(" {} ", packager)).bold().white().on_blue(),
-                        "npm" => style(format!(" {} ", packager)).bold().white().on_red(),
                         "cargo" => style(format!(" {} ", packager)).bold().black().on_green(),
+                        "composer" => style(format!(" {} ", packager)).bold().black().on_yellow(),
+                        "gem" => style(format!(" {} ", packager)).bold().white().on_red(),
+                        "npm" => style(format!(" {} ", packager)).bold().white().on_red(),
+                        "pip" => style(format!(" {} ", packager)).bold().white().on_blue(),
                         _ => style(format!(" {} ", packager)).bold().white(),
                     };
                     println!("{}", p);
